@@ -1,7 +1,7 @@
 /*
  * messasy
  *
- * Copyright (C) 2006,2007,2008 DesigNET, INC.
+ * Copyright (C) 2006,2007,2008,2009 DesigNET, INC.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,24 +20,25 @@
 
 /*
  * $RCSfile: filter.h,v $
- * $Revision: 1.3 $
- * $Date: 2008/12/15 10:10:56 $
+ * $Revision: 1.12 $
+ * $Date: 2009/10/22 04:03:31 $
  */
 
-#ifndef _MSY_FILTER_H_
-#define _MSY_FILTER_H_
 
-#define FL_START	1
-#define FL_BRACKET	2
-#define FL_NORMAL	3
-#define FL_END		4
-#define FL_SKIP		5
+#define FROM 1
+#define TO   2
 
-#define FL_ESCAPE_IN	1
-#define FL_ESCAPE_OUT	0
+/* ץȥ */
+extern int make_savelist(struct strset *from,
+                         struct strlist *rcptlist,
+                         struct strlist **savelist_h,
+                         struct strlist **savelist_t,
+                         struct config *cfg,
+                         unsigned int s_id);
+extern int check_header_regex(char *, char *, regex_t *);
 
-int filter_getaddress(char *, char *, int);
-int filter_address_search(char *, struct filter *);
-int filter_domain_search(char *, struct filter *);
+#ifndef _FILTER_H_
+#define _FILTER_H_
 
-#endif /* ! _MSY_FILTER_H_ */
+
+#endif // _FILTER_H_
